@@ -445,6 +445,9 @@ editor_page_constructed (GObject *object)
   g_binding_group_bind (self->settings_bindings, "insert-spaces-instead-of-tabs",
                         self->view, "insert-spaces-instead-of-tabs",
                         G_BINDING_SYNC_CREATE);
+  g_binding_group_bind (self->settings_bindings, "implicit-trailing-newline",
+                        self->document, "implicit-trailing-newline",
+                        G_BINDING_SYNC_CREATE);
   g_binding_group_bind (self->settings_bindings, "right-margin-position",
                         self->view, "right-margin-position",
                         G_BINDING_SYNC_CREATE);
@@ -688,7 +691,8 @@ editor_page_dispose (GObject *object)
 {
   EditorPage *self = (EditorPage *)object;
 
-  _editor_document_shutdown (self->document);
+  if (self->document != NULL)
+    _editor_document_shutdown (self->document);
 
   g_cancellable_cancel (self->cancellable);
   g_clear_object (&self->cancellable);
@@ -1108,7 +1112,7 @@ editor_page_dup_subtitle (EditorPage *self)
           return g_strdup_printf (_("%s (Administrator)"), path);
         }
 
-      return g_steal_pointer (&uri);
+      return g_uri_unescape_string (uri, NULL);
     }
 
   peek = g_file_peek_path (dir);
@@ -1146,7 +1150,7 @@ editor_page_save_cb (GObject      *object,
   g_autoptr(EditorPage) self = user_data;
   g_autoptr(GError) error = NULL;
   GtkNative *parent;
-  GtkWidget *dialog;
+  AdwDialog *dialog;
 
   g_assert (EDITOR_IS_DOCUMENT (document));
   g_assert (G_IS_ASYNC_RESULT (result));
@@ -1161,10 +1165,10 @@ editor_page_save_cb (GObject      *object,
   g_warning ("Failed to save document: %s", error->message);
 
   parent = gtk_widget_get_native (GTK_WIDGET (self));
-  dialog = adw_message_dialog_new (GTK_WINDOW (parent), _("Failed to save document"), NULL);
-  adw_message_dialog_add_response (ADW_MESSAGE_DIALOG (dialog), "close", _("_Close"));
-  adw_message_dialog_format_body (ADW_MESSAGE_DIALOG (dialog), "%s", error->message);
-  gtk_window_present (GTK_WINDOW (dialog));
+  dialog = adw_alert_dialog_new (_("Failed to save document"), NULL);
+  adw_alert_dialog_add_response (ADW_ALERT_DIALOG (dialog), "close", _("_Close"));
+  adw_alert_dialog_format_body (ADW_ALERT_DIALOG (dialog), "%s", error->message);
+  adw_dialog_present (dialog, GTK_WIDGET (parent));
 }
 
 void
@@ -1201,6 +1205,7 @@ editor_page_save_as_cb (EditorPage           *self,
 
       if ((dest = gtk_file_chooser_get_file (GTK_FILE_CHOOSER (native))))
         {
+          const GtkSourceEncoding *encoding = _editor_file_chooser_get_encoding (GTK_FILE_CHOOSER (native));
           GtkSourceNewlineType crlf = _editor_file_chooser_get_line_ending (GTK_FILE_CHOOSER (native));
           g_autoptr(GFile) directory = gtk_file_chooser_get_current_folder (GTK_FILE_CHOOSER (native));
 
@@ -1214,6 +1219,7 @@ editor_page_save_as_cb (EditorPage           *self,
               g_settings_set_string (settings, "last-save-directory", uri);
             }
 
+          _editor_document_set_encoding (self->document, encoding);
           _editor_document_set_newline_type (self->document, crlf);
           _editor_document_save_async (self->document,
                                        dest,
@@ -1254,7 +1260,8 @@ _editor_page_save_as (EditorPage *self,
                                         _("Save"),
                                         _("Cancel"));
 
-  _editor_file_chooser_add_encodings (GTK_FILE_CHOOSER (native));
+  _editor_file_chooser_add_encodings (GTK_FILE_CHOOSER (native),
+                                      _editor_document_get_encoding (self->document));
   _editor_file_chooser_add_line_endings (GTK_FILE_CHOOSER (native),
                                          _editor_document_get_newline_type (self->document));
 
@@ -1315,19 +1322,24 @@ handle_print_result (EditorPage              *self,
                      GtkPrintOperation       *operation,
                      GtkPrintOperationResult  result)
 {
+  g_autoptr(GError) error = NULL;
+
   g_assert (EDITOR_IS_PAGE (self));
-  g_assert (GTK_IS_PRINT_OPERATION (operation));
+  g_assert (EDITOR_IS_PRINT_OPERATION (operation));
 
   if (result == GTK_PRINT_OPERATION_RESULT_ERROR)
     {
-      g_autoptr(GError) error = NULL;
-
       gtk_print_operation_get_error (operation, &error);
 
-      g_warning ("%s", error->message);
+      g_warning ("Print Failed: %s", error->message);
 
       /* TODO: Display error message with dialog */
     }
+  else if (result == GTK_PRINT_OPERATION_RESULT_APPLY)
+    {
+      if (!editor_print_operation_save (EDITOR_PRINT_OPERATION (operation), &error))
+        g_warning ("Failed to save print settings: %s", error->message);
+    }
 }
 
 static void
@@ -1337,7 +1349,7 @@ print_done (GtkPrintOperation       *operation,
 {
   EditorPage *self = user_data;
 
-  g_assert (GTK_IS_PRINT_OPERATION (operation));
+  g_assert (EDITOR_IS_PRINT_OPERATION (operation));
   g_assert (EDITOR_IS_PAGE (self));
 
   handle_print_result (self, operation, result);
