@@ -31,6 +31,31 @@
 
 G_DEFINE_TYPE (EditorSearchBar, editor_search_bar, GTK_TYPE_WIDGET)
 
+typedef struct
+{
+  GWeakRef wr;
+} WeakHold;
+
+static WeakHold *
+weak_hold_new (EditorSearchBar *self)
+{
+  WeakHold *wh = g_new0 (WeakHold, 1);
+  g_weak_ref_init (&wh->wr, self);
+  return wh;
+}
+
+static void
+weak_hold_free (WeakHold *wh)
+{
+  if (wh != NULL)
+    {
+      g_weak_ref_clear (&wh->wr);
+      g_free (wh);
+    }
+}
+
+G_DEFINE_AUTOPTR_CLEANUP_FUNC (WeakHold, weak_hold_free)
+
 enum {
   PROP_0,
   PROP_CAN_MOVE,
@@ -196,17 +221,23 @@ editor_search_bar_move_next_forward_cb (GObject      *object,
                                         gpointer      user_data)
 {
   GtkSourceSearchContext *context = (GtkSourceSearchContext *)object;
-  g_autoptr(EditorSearchBar) self = user_data;
+  g_autoptr(WeakHold) wh = user_data;
+  g_autoptr(EditorSearchBar) self = NULL;
   g_autoptr(GError) error = NULL;
   GtkSourceBuffer *buffer;
   GtkTextIter begin;
   GtkTextIter end;
   gboolean has_wrapped = FALSE;
 
-  g_assert (EDITOR_IS_SEARCH_BAR (self));
+  g_assert (wh != NULL);
   g_assert (G_IS_ASYNC_RESULT (result));
   g_assert (GTK_SOURCE_IS_SEARCH_CONTEXT (context));
 
+  if (!(self = g_weak_ref_get (&wh->wr)))
+    return;
+
+  g_assert (EDITOR_IS_SEARCH_BAR (self));
+
   if (!gtk_source_search_context_forward_finish (context, result, &begin, &end, &has_wrapped, &error))
     {
       if (error != NULL)
@@ -222,6 +253,15 @@ editor_search_bar_move_next_forward_cb (GObject      *object,
     gtk_widget_activate_action (GTK_WIDGET (self), "search.hide", NULL);
 }
 
+static void
+reset_cancellable (EditorSearchBar *self)
+{
+  g_assert (EDITOR_IS_SEARCH_BAR (self));
+
+  g_clear_object (&self->cancellable);
+  self->cancellable = g_cancellable_new ();
+}
+
 void
 _editor_search_bar_move_next (EditorSearchBar *self,
                               gboolean         hide_after_move)
@@ -241,12 +281,13 @@ _editor_search_bar_move_next (EditorSearchBar *self,
   buffer = gtk_source_search_context_get_buffer (self->context);
   gtk_text_buffer_get_selection_bounds (GTK_TEXT_BUFFER (buffer), &begin, &end);
   gtk_text_iter_order (&begin, &end);
+  reset_cancellable (self);
 
   gtk_source_search_context_forward_async (self->context,
                                            &end,
-                                           NULL,
+                                           self->cancellable,
                                            editor_search_bar_move_next_forward_cb,
-                                           g_object_ref (self));
+                                           weak_hold_new (self));
 }
 
 void
@@ -268,13 +309,14 @@ _editor_search_bar_move_previous (EditorSearchBar *self,
   buffer = gtk_source_search_context_get_buffer (self->context);
   gtk_text_buffer_get_selection_bounds (GTK_TEXT_BUFFER (buffer), &begin, &end);
   gtk_text_iter_order (&begin, &end);
+  reset_cancellable (self);
 
   gtk_source_search_context_backward_async (self->context,
                                             &begin,
-                                            NULL,
+                                            self->cancellable,
                                             /* XXX: fixme */
                                             editor_search_bar_move_next_forward_cb,
-                                            g_object_ref (self));
+                                            weak_hold_new (self));
 }
 
 static gboolean
@@ -416,6 +458,9 @@ editor_search_bar_dispose (GObject *object)
 {
   EditorSearchBar *self = (EditorSearchBar *)object;
 
+  g_cancellable_cancel (self->cancellable);
+  g_clear_object (&self->context);
+
   gtk_widget_dispose_template (GTK_WIDGET (self), EDITOR_TYPE_SEARCH_BAR);
 
   g_clear_pointer ((GtkWidget **)&self->grid, gtk_widget_unparent);
@@ -433,6 +478,7 @@ editor_search_bar_finalize (GObject *object)
 
   g_clear_object (&self->context);
   g_clear_object (&self->settings);
+  g_clear_object (&self->cancellable);
 
   G_OBJECT_CLASS (editor_search_bar_parent_class)->finalize (object);
 }
@@ -581,6 +627,8 @@ editor_search_bar_class_init (EditorSearchBarClass *klass)
 static void
 editor_search_bar_init (EditorSearchBar *self)
 {
+  self->cancellable = g_cancellable_new ();
+
   gtk_widget_init_template (GTK_WIDGET (self));
 
   /* Setup focus chain */
