@@ -97,7 +97,7 @@ editor_window_actions_confirm_save_cb (GtkWidget  *widget,
   EditorWindow *self = (EditorWindow *)widget;
   g_autofree gchar *title = NULL;
   EditorPage *page;
-  GtkWidget *dialog;
+  AdwDialog *dialog;
 
   g_assert (EDITOR_IS_WINDOW (self));
 
@@ -105,19 +105,18 @@ editor_window_actions_confirm_save_cb (GtkWidget  *widget,
     return;
 
   title = editor_page_dup_title (page);
-  dialog = adw_message_dialog_new (GTK_WINDOW (self),
-                                   NULL,
-                                   _("Saving changes will replace the previously saved version."));
-  adw_message_dialog_format_heading (ADW_MESSAGE_DIALOG (dialog),
-                                     /* translators: %s is replaced with the document title */
-                                     _("Save Changes to “%s”?"),
-                                     title);
-  adw_message_dialog_add_responses (ADW_MESSAGE_DIALOG (dialog),
-                                    "cancel", _("_Cancel"),
-                                    "save", _("_Save"),
-                                    NULL);
-  adw_message_dialog_set_response_appearance (ADW_MESSAGE_DIALOG (dialog),
-                                              "save", ADW_RESPONSE_DESTRUCTIVE);
+  dialog = adw_alert_dialog_new (NULL,
+                                 _("Saving changes will replace the previously saved version."));
+  adw_alert_dialog_format_heading (ADW_ALERT_DIALOG (dialog),
+                                   /* translators: %s is replaced with the document title */
+                                   _("Save Changes to “%s”?"),
+                                   title);
+  adw_alert_dialog_add_responses (ADW_ALERT_DIALOG (dialog),
+                                  "cancel", _("_Cancel"),
+                                  "save", _("_Save"),
+                                  NULL);
+  adw_alert_dialog_set_response_appearance (ADW_ALERT_DIALOG (dialog),
+                                            "save", ADW_RESPONSE_DESTRUCTIVE);
 
   g_signal_connect_object (dialog,
                            "response::save",
@@ -125,7 +124,7 @@ editor_window_actions_confirm_save_cb (GtkWidget  *widget,
                            page,
                            G_CONNECT_SWAPPED);
 
-  gtk_window_present (GTK_WINDOW (dialog));
+  adw_dialog_present (dialog, widget);
 }
 
 static void
@@ -178,10 +177,7 @@ editor_window_actions_change_language_cb (GtkWidget  *widget,
 
   document = editor_page_get_document (page);
 
-  dialog = editor_language_dialog_new (EDITOR_APPLICATION_DEFAULT);
-  gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (self));
-  gtk_window_set_destroy_with_parent (GTK_WINDOW (dialog), TRUE);
-  gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
+  dialog = editor_language_dialog_new ();
 
   g_object_bind_property (document, "language", dialog, "language",
                           G_BINDING_SYNC_CREATE | G_BINDING_BIDIRECTIONAL);
@@ -197,7 +193,7 @@ editor_window_actions_change_language_cb (GtkWidget  *widget,
                            document,
                            G_CONNECT_SWAPPED);
 
-  gtk_window_present (GTK_WINDOW (dialog));
+  adw_dialog_present (ADW_DIALOG (dialog), widget);
 }
 
 static void
@@ -222,7 +218,7 @@ editor_window_actions_confirm_discard_changes_cb (GtkWidget  *widget,
   EditorWindow *self = (EditorWindow *)widget;
   g_autofree gchar *title = NULL;
   EditorPage *page;
-  GtkWidget *dialog;
+  AdwDialog *dialog;
 
   g_assert (EDITOR_IS_WINDOW (self));
 
@@ -230,18 +226,16 @@ editor_window_actions_confirm_discard_changes_cb (GtkWidget  *widget,
     return;
 
   title = editor_page_dup_title (page);
-  dialog = adw_message_dialog_new (GTK_WINDOW (self),
-                                   NULL,
-                                   _("Unsaved changes will be permanently lost."));
-  adw_message_dialog_format_heading (ADW_MESSAGE_DIALOG (dialog),
+  dialog = adw_alert_dialog_new (NULL, _("Unsaved changes will be permanently lost."));
+  adw_alert_dialog_format_heading (ADW_ALERT_DIALOG (dialog),
                                      /* translators: %s is replaced with the document title */
                                      _("Discard Changes to “%s”?"),
                                      title);
-  adw_message_dialog_add_responses (ADW_MESSAGE_DIALOG (dialog),
+  adw_alert_dialog_add_responses (ADW_ALERT_DIALOG (dialog),
                                     "cancel", _("_Cancel"),
                                     "discard", _("_Discard"),
                                     NULL);
-  adw_message_dialog_set_response_appearance (ADW_MESSAGE_DIALOG (dialog),
+  adw_alert_dialog_set_response_appearance (ADW_ALERT_DIALOG (dialog),
                                               "discard", ADW_RESPONSE_DESTRUCTIVE);
 
   g_signal_connect_object (dialog,
@@ -250,7 +244,7 @@ editor_window_actions_confirm_discard_changes_cb (GtkWidget  *widget,
                            page,
                            G_CONNECT_SWAPPED);
 
-  gtk_window_present (GTK_WINDOW (dialog));
+  adw_dialog_present (dialog, widget);
 }
 
 static void
@@ -391,7 +385,7 @@ editor_window_actions_open_cb (GtkWidget  *widget,
   gtk_file_chooser_set_filter (GTK_FILE_CHOOSER (native), text_files);
 #endif
 
-  _editor_file_chooser_add_encodings (GTK_FILE_CHOOSER (native));
+  _editor_file_chooser_add_encodings (GTK_FILE_CHOOSER (native), NULL);
 
   gtk_file_chooser_set_select_multiple (GTK_FILE_CHOOSER (native), TRUE);
 
@@ -535,12 +529,12 @@ editor_window_actions_show_preferences_cb (GtkWidget  *widget,
                                            GVariant   *param)
 {
   EditorWindow *self = (EditorWindow *)widget;
-  GtkWidget *dialog;
+  AdwDialog *dialog;
 
   g_assert (EDITOR_IS_WINDOW (self));
 
-  dialog = editor_preferences_dialog_new (EDITOR_APPLICATION_DEFAULT, self);
-  gtk_window_present (GTK_WINDOW (dialog));
+  dialog = editor_preferences_dialog_new (self);
+  adw_dialog_present (dialog, widget);
 }
 
 static void
